#!/bin/bash
#################################################################################
# Exports all MySQL tables relevant to eXtensible Catalog Drupal Toolkit settings
#################################################################################

usage(){
  echo "Usage: $0 database user password"
  exit 1
}

export_csv() {
  if [ $1 ]
  then
    TABLE=$1
    mysql -u $USER -p$PW $DB -B -e "select * from $TABLE;" | sed 's/\t/";"/g;s/^/"/;s/$/"/;s/\n//g;s/"NULL"/NULL/g' > $TABLE.csv
  fi
}

export_xml() {
  if [ $1 ]
  then
    TABLE=$1
    mysql -u $USER -p$PW $DB --xml -e "select * from $TABLE" | sed 's/<field name="\([^<>]*\)">\([^<>]*\)<\/field>/<\1>\2<\/\1>/g' > $TABLE.xml
  fi
}

if [ -z $1 ]
then
  echo ERROR: Missing database, user and password parameters
  usage
fi

if [ -z $2 ]
then
  echo ERROR: Missing user and password parameters
  usage
fi

if [ -z $3 ]
then
  echo ERROR: Missing password parameter
  usage
fi

DB=$1
USER=$2
PW=$3

# xc
export_csv xc_settings

# xc_browse
export_csv xc_browse_ui
export_csv xc_browse_tab
export_csv xc_browse_element
export_csv xc_browse_list

# xc_index
export_csv xc_index_attribute_to_field
export_csv xc_index_field_to_facet
export_csv xc_index_field_type
export_csv xc_index_super_location
export_csv xc_index_sortable_field
export_xml xc_index_facet

# xc_metadata
export_csv xc_location

# xc_search
export_csv xc_search_mlt
export_csv xc_search_highlighter
export_csv xc_search_date_facet_properties
export_csv xc_search_date_facet_properties_additional
export_csv xc_search_field_facet_properties
export_csv xc_search_query_facet_properties
export_csv xc_search_facet_group
export_csv xc_search_facet_field
export_csv xc_search_ui
export_csv xc_search_ui_boosting
export_csv xc_search_sortoption
export_csv xc_search_location
export_csv xc_search_full_record_display
export_xml xc_search_display_template
export_xml xc_search_display_template_element

# xc_solr
export_csv xc_solr_field_type
export_csv xc_solr_servers

# xc_sql
export_csv xc_sql_storage

